@@ -6,8 +6,8 @@ from pathlib import Path
 from textwrap import dedent
 from typing import TYPE_CHECKING, Any, Callable, Sequence, cast
 
-from _griffe.c3linear import c3linear_merge
 from griffe import Docstring
+from griffe._internal.c3linear import c3linear_merge
 from tree_sitter import Node
 
 from maxx.enums import AccessKind, ArgumentKind, Kind
